/**
 * Jackpine Spatial Database Benchmark 
 *  Copyright (C) 2010 University of Toronto
 * 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * Developer: S. Ray
 * Contributor(s): 
 */

package edu.toronto.cs.jackpine.benchmark.scenarios;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Random;
import java.util.StringTokenizer;

import com.ibm.spatial.geom.Geometry;
import com.ibm.spatial.io.IfxSQLData;
import com.ibm.spatial.srs.CoordRefManager;

import edu.toronto.cs.jackpine.benchmark.db.SpatialSqlDialect;
import edu.toronto.cs.jackpine.benchmark.scenarios.macroscenario.StudentCampusVisitScenario;
import edu.toronto.cs.jackpine.benchmark.scenarios.macroscenario.TouristVisitScenario;

public class MapBrowsingScenario4Informix extends MapBrowsingMacroScenario {
	
	
	
	public void runMapBrowsingScenario4Informix(Connection conn) throws SQLException, ClassNotFoundException
	{	  
		  java.util.Map typeMap =  null;
		  try {
			  typeMap=IfxSQLData.enableTypes(conn);
			  // set the CoordRefManager connection
	  		  CoordRefManager crm=CoordRefManager.getInstance();
	  		  crm.setConnection(conn);
		  }
		  catch (Exception e) {
			  e.printStackTrace();
		  }
		  
		 logger.warn(siteSearchPstmt.toString()); 
	  	 ResultSet r = siteSearchPstmt.executeQuery();
	  	 String location = "";
	  	 String name = "";
	  	 double locLon = 0;
	  	 double locLat = 0;
	  	 
	  	 int siteGid = 0;
	  	 double siteFoundLocLon = 0;
	  	 double siteFoundLocLat = 0;
	  	 
	  	 if (r.next())   {
	  		   siteGid = r.getInt(1);	 //gid or 
	  	       name = r.getString("name");
	  	       //location = r.getString("location");
	  	       Geometry g = (Geometry)r.getObject("location", typeMap);
	  	       location =  g.asText();
	  	       
	  	       if (!location.equals("")) {
	  	        		location = location.substring(location.indexOf("(")+1, location.indexOf(")"));
	  	        		StringTokenizer st = new  StringTokenizer(location," ");
	  	        		locLon = Double.parseDouble(st.nextToken());
	  	        		locLat = Double.parseDouble(st.nextToken());
	  	        		
	  	        		siteFoundLocLon = locLon;
	  	        	    siteFoundLocLat = locLat;	
	  	        		displayMap(locLon,locLat,conn);
	  	       }
	  	       
	  	 }
	  	 r.close();
	  	 
	  	 	if (siteFoundLocLon != 0 &&  siteFoundLocLat != 0) {
	  	 		 PreparedStatement searchScenarioPstmt = null;
	  	 		 
		    	 String pointParam = "POINT("+siteFoundLocLon+" "+siteFoundLocLat+")";
		    	 for (int i=0;i<searchScenarioPstmtArray.length;i++) {
		    		 searchScenarioPstmt = searchScenarioPstmtArray[i];
			    	 if ( searchScenarioPstmt != null ) {	 
			    		 searchScenarioPstmt.setString(1, pointParam);
			    		 searchScenarioPstmt.setString(2, pointParam);
			    		 searchScenarioPstmt.setInt(3,siteGid);
			    		 
			    		 logger.warn(searchScenarioPstmt.toString());
			    	     r = searchScenarioPstmt.executeQuery();
			    	     location = "";
			    	     name = "";
			    	     locLon = 0;
			    	     locLat = 0;
			    	     while (r.next())   {
			    	    	 name = r.getString("name");
			    	    	 //location = r.getString("location");
			    	    	 Geometry g = (Geometry)r.getObject("location", typeMap);
			    	  	     location =  g.asText();

			    	    	 if (!location.equals("")) {
			    	    		 location = location.substring(location.indexOf("(")+1, location.indexOf(")"));
			    	    	     StringTokenizer st = new  StringTokenizer(location," ");
			    	    	     locLon = Double.parseDouble(st.nextToken());
			    	    	     locLat = Double.parseDouble(st.nextToken());
			    	    	        		
			    	    	     displayMap(locLon,locLat,conn);
			    	    	 }      
			    	     }
			    	     r.close();
			    	 }
		    	 } // end for
		    }
			 
	  }
	
	void prepare4Informix(SpatialSqlDialect dial, Connection con)  throws Exception {

		 dialect = dial;
		 conn = con;
		 
		 scenarioPickerRnd = new Random(System.currentTimeMillis());
		 //int pickedScenario = scenarioPickerRnd.nextInt(MAX_NUM_SCENARIOS); 
		 int pickedScenario = 1; //TODO: change it to previous line
		 
		 if (pickedScenario==0) {
			 visitScenario =  new StudentCampusVisitScenario();
		 }
		 else if (pickedScenario==1) {
			 visitScenario =  new TouristVisitScenario();
		 }
		 //if more scenarios...
		 		  
		 // prepare the queries
		 String sql = dialect.getMapSearchSiteSearchQuery(visitScenario);
		 logger.warn(" ????? Preparing: " + sql);
		 siteSearchPstmt  =  conn.prepareStatement(sql,ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
		 
		 int numQry= visitScenario.getTotalVisitSearches();
		 searchScenarioPstmtArray =  new PreparedStatement[numQry];
		 
		 String[] sqls = dialect.getMapSearchScenarioQueries(visitScenario);
		 for (int i=0;i<numQry;i++) {
			 if (sqls[i] != null) {
				 logger.warn(" ????? Preparing: " + sqls[i]);		 
				 searchScenarioPstmtArray[i]=conn.prepareStatement(sqls[i],ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
			 }
		 }
		 
		 numQry= visitScenario.getTotalMapLayers();
		 boundingBoxPstmtArray=  new PreparedStatement[numQry];
		 
		 sqls = dialect.getMapBrowseBoundingBoxQueries();
		 for (int i=0;i<numQry;i++) {
			 if (sqls[i] != null) {
				 logger.warn(" ????? Preparing: " + sqls[i]);
				 boundingBoxPstmtArray[i]=conn.prepareStatement(sqls[i],ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
			 }
		 }
 	  
	}
	
	void cleanup4Informix() throws Exception {
		 // Clean up connections. 
		siteSearchPstmt.close();
		  
	    for (int i = 0; i < searchScenarioPstmtArray.length; i++) {
	    	if (searchScenarioPstmtArray[i] != null)
	    		searchScenarioPstmtArray[i].close();
	    }
	    
	    for (int i = 0; i < boundingBoxPstmtArray.length; i++) {
	    	if (boundingBoxPstmtArray[i] != null)
	    		boundingBoxPstmtArray[i].close();
	    }
	    
	    if (conn != null)
	      conn.close();
	  }
}
